import 'dart:async';

import 'package:flutter/services.dart';
import 'package:fpjs_pro_plugin/region.dart';

/// A plugin that accesses native FingerprintJS Pro libraries to get a device identifier
class FpjsProPlugin {
  static const channelName = 'fpjs_pro_plugin';

  /// A channel used for communication with the native libraries
  static const MethodChannel _channel = MethodChannel(channelName);

  static var _isInitialized = false;

  /// Initializes the native FingerprintJS Pro client
  /// Throws a [PlatformException] if [apiKey] is missing
  static Future<void> initFpjs(String apiKey,
      {String? endpoint, Region? region}) async {
    await _channel.invokeMethod('init', {
      'apiToken': apiKey,
      'endpoint': endpoint,
      'region': region?.stringValue,
    });
    _isInitialized = true;
  }

  /// Returns the visitor id generated by the native FingerprintJS Pro client
  /// Support [tags](https://dev.fingerprintjs.com/docs/quick-start-guide#tagging-your-requests)
  /// Throws a [PlatformException] if identification request fails for any reason
  static Future<String?> getVisitorId({Map<String, dynamic>? tags}) async {
    if (!_isInitialized) {
      throw Exception(
          'You need to initialize the FPJS Client first by calling the "initFpjs" method');
    }

    final String? visitorId = await _channel.invokeMethod('getVisitorId');
    return visitorId;
  }
}
